@@ -81,13 +81,15 @@ do
 
         # Clone, bootstrap, buildout
         cd ${DEPLOY_DIR}/
+
+        # Nuke source when level 3
+        if [ $LEVEL == 3 ]; then
+            sudo -u $USER rm -rf $THEDIR
+        fi
+
         IS_NEW=0
         if [ -d $THEDIR ]; then
             cd $THEDIR
-            if [ $LEVEL == 3 ]; then
-                sudo -u $USER rm -rf src
-                sudo -u $USER rm -rf $PREFIX
-            fi
             sudo -u $USER git checkout $BRANCH
             sudo -u $USER git pull
         else
@@ -110,6 +112,7 @@ do
             sudo -u $USER ./bin/$THEDIR syncdb
             sudo -u $USER ./bin/$THEDIR migrate
             sudo -u $USER ./bin/$THEDIR load_photosizes
+            sudo -u $USER ./bin/$THEDIR loaddata skeleton/fixtures/sites.json
         fi
 
         sudo -u $USER rm -rf static
